@@ -4,8 +4,8 @@ use strict;
 use warnings;
 use UNIVERSAL::require;
 use YAML::Syck;
-our $VERSION='0.67';
-
+our $VERSION='0.70';
+use try;
 use File::Copy;
 
 sub new{
@@ -521,9 +521,13 @@ sub get_value{
   my ($self, $name)=@_;
   my $result='';
   
-  if (($self->{request}->{$self->{prefix}.$name}) ||($self->{request}->{$self->{prefix}.$name.'_submit'})){  
-      $result=$self->{element}[$self->{element_index}->{$self->{prefix}.$name}->{index}]->get_value();
-  }  
+  
+   try{
+       my $id=$self->{element_index}->{$self->{prefix}.$name}->{index};
+   }
+   
+   $result=$self->{element}[$id]->get_value() if ($id);
+  
   return $result;
 }
 
